import type { AgentMessage } from '../../../agent/AgentMessage';
import type { InboundMessageContext } from '../../../agent/models/InboundMessageContext';
import type { ConnectionRecord } from '../../connections';
import type { Routing } from '../../connections/services/ConnectionService';
import type { KeylistUpdateResponseMessage, MediationDenyMessage, MediationGrantMessage } from '../messages';
import type { StatusMessage, MessageDeliveryMessage } from '../protocol';
import type { GetRoutingOptions } from './RoutingService';
import { AgentConfig } from '../../../agent/AgentConfig';
import { EventEmitter } from '../../../agent/EventEmitter';
import { MessageSender } from '../../../agent/MessageSender';
import { ConnectionService } from '../../connections/services/ConnectionService';
import { MediationRequestMessage } from '../messages';
import { KeylistUpdateMessage } from '../messages/KeylistUpdateMessage';
import { DeliveryRequestMessage, MessagesReceivedMessage, StatusRequestMessage } from '../protocol/pickup/v2/messages';
import { MediationRecord } from '../repository/MediationRecord';
import { MediationRepository } from '../repository/MediationRepository';
export declare class MediationRecipientService {
    private mediationRepository;
    private eventEmitter;
    private connectionService;
    private messageSender;
    private config;
    constructor(connectionService: ConnectionService, messageSender: MessageSender, config: AgentConfig, mediatorRepository: MediationRepository, eventEmitter: EventEmitter);
    createStatusRequest(mediationRecord: MediationRecord, config?: {
        recipientKey?: string;
    }): Promise<StatusRequestMessage>;
    createRequest(connection: ConnectionRecord): Promise<MediationProtocolMsgReturnType<MediationRequestMessage>>;
    processMediationGrant(messageContext: InboundMessageContext<MediationGrantMessage>): Promise<MediationRecord>;
    processKeylistUpdateResults(messageContext: InboundMessageContext<KeylistUpdateResponseMessage>): Promise<void>;
    keylistUpdateAndAwait(mediationRecord: MediationRecord, verKey: string, timeoutMs?: number): Promise<MediationRecord>;
    createKeylistUpdateMessage(verkey: string): KeylistUpdateMessage;
    addMediationRouting(routing: Routing, { mediatorId, useDefaultMediator }?: GetRoutingOptions): Promise<Routing>;
    processMediationDeny(messageContext: InboundMessageContext<MediationDenyMessage>): Promise<MediationRecord>;
    processStatus(messageContext: InboundMessageContext<StatusMessage>): Promise<DeliveryRequestMessage | null>;
    processDelivery(messageContext: InboundMessageContext<MessageDeliveryMessage>): Promise<MessagesReceivedMessage>;
    /**
     * Update the record to a new state and emit an state changed event. Also updates the record
     * in storage.
     *
     * @param MediationRecord The proof record to update the state for
     * @param newState The state to update to
     *
     */
    private updateState;
    private emitStateChangedEvent;
    getById(id: string): Promise<MediationRecord>;
    findByConnectionId(connectionId: string): Promise<MediationRecord | null>;
    getMediators(): Promise<MediationRecord[]>;
    findDefaultMediator(): Promise<MediationRecord | null>;
    discoverMediation(mediatorId?: string): Promise<MediationRecord | undefined>;
    setDefaultMediator(mediator: MediationRecord): Promise<void>;
    clearDefaultMediator(): Promise<void>;
}
export interface MediationProtocolMsgReturnType<MessageType extends AgentMessage> {
    message: MessageType;
    mediationRecord: MediationRecord;
}
